# ListInboxItemsSummary

An inbox holds messages for a user. These messages track whether they have been read, and can be deleted/marked unread/etc. The inbox query summary describes the state of an inbox when filtered. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_total** | **float** | The number of messages in the inbox. | 
**count_unread** | **float** | The number of messages in the inbox which have not been marked as read. | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


